@@ -1037,6 +1037,7 @@ cached: list[str] = [
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
+    "aws-ec2-trafficmirrorfilterrule.json",
     "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
@@ -1118,6 +1119,7 @@ cached: list[str] = [
     "aws-emr-studio.json",
     "aws-emr-studiosessionmapping.json",
     "aws-emrcontainers-virtualcluster.json",
+    "aws-emrserverless-application.json",
     "aws-events-apidestination.json",
     "aws-events-archive.json",
     "aws-events-connection.json",
@@ -1222,6 +1224,7 @@ cached: list[str] = [
     "aws-iot-topicruledestination.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
+    "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
@@ -1361,6 +1364,7 @@ cached: list[str] = [
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
     "aws-resourceexplorer2-defaultviewassociation.json",
     "aws-resourceexplorer2-index.json",
