@@ -14,8 +14,9 @@ import regex as re
 
 import cfnlint.conditions
 import cfnlint.helpers
-from cfnlint._typing import CheckValueFn, Path
-from cfnlint.context import Context, create_context_for_template
+from cfnlint._typing import CheckValueFn
+from cfnlint._typing import Path as CfnPath
+from cfnlint.context import Context, ParameterSet, create_context_for_template
 from cfnlint.context.conditions.exceptions import Unsatisfiable
 from cfnlint.decode.node import dict_node, list_node
 from cfnlint.graph import Graph
@@ -52,6 +53,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
         filename: str | None,
         template: dict[str, Any],
         regions: list[str] | None = None,
+        parameter_sets: list[ParameterSet] | None = None,
     ):
         """Initialize a Template instance.
 
@@ -60,10 +62,9 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
             template (dict[str, Any]): The dictionary representing the CloudFormation template.
             regions (list[str] | None): A list of AWS regions associated with the template.
         """
-        if regions is None:
-            self.regions = [cfnlint.helpers.REGION_PRIMARY]
-        else:
-            self.regions = regions
+
+        self.regions = regions or [cfnlint.helpers.REGION_PRIMARY]
+
         self.filename = filename
         self.template = template
         self.transform_pre: dict[str, Any] = {}
@@ -94,6 +95,8 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
             LOGGER.info("Encountered unknown error while building graph: %s", err)
 
         self.context = create_context_for_template(self)
+        if parameter_sets:
+            self.context = self.context.evolve(parameter_sets=parameter_sets)
         self.search_deep_keys = functools.lru_cache()(self.search_deep_keys)  # type: ignore
 
     def __deepcopy__(self, memo):
@@ -347,7 +350,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
         return results
 
     # pylint: disable=dangerous-default-value
-    def _search_deep_keys(self, searchText: str | re.Pattern, cfndict, path: Path):
+    def _search_deep_keys(self, searchText: str | re.Pattern, cfndict, path: CfnPath):
         """Search deep for keys and get their values.
 
         Args:
@@ -361,7 +364,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
         keys = []
         if isinstance(cfndict, dict):
             for key in cfndict:
-                pathprop: Path = path[:]
+                pathprop: CfnPath = path[:]
                 pathprop.append(key)
                 if isinstance(searchText, str):
                     if key == searchText:
@@ -501,7 +504,9 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
 
         yield from _get_cfn_path(path, self.template, context)
 
-    def get_condition_values(self, template, path: Path | None) -> list[dict[str, Any]]:
+    def get_condition_values(
+        self, template, path: CfnPath | None
+    ) -> list[dict[str, Any]]:
         """
         Evaluates conditions in the provided CloudFormation template and returns the values.
 
@@ -558,7 +563,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
 
         return matches
 
-    def get_values(self, obj, key, path: Path | None = None):
+    def get_values(self, obj, key, path: CfnPath | None = None):
         """
         Logic for getting the value of a key in the provided object.
 
@@ -684,7 +689,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
 
         return results
 
-    def get_location_yaml(self, text: Any, path: Path):
+    def get_location_yaml(self, text: Any, path: CfnPath):
         """
         Get the location information for the given YAML text and path.
 
@@ -740,7 +745,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
         self,
         obj: dict[str, Any],
         key: str,
-        path: Path,
+        path: CfnPath,
         check_value: CheckValueFn | None = None,
         check_ref: CheckValueFn | None = None,
         check_get_att: CheckValueFn | None = None,
@@ -849,7 +854,9 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
 
         return matches
 
-    def is_resource_available(self, path: Path, resource: str) -> list[dict[str, bool]]:
+    def is_resource_available(
+        self, path: CfnPath, resource: str
+    ) -> list[dict[str, bool]]:
         """
         Compares a path to a resource to see if it is available.
 
@@ -901,7 +908,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
         return results
 
     def get_object_without_nested_conditions(
-        self, obj: dict | list, path: Path, region: str | None = None
+        self, obj: dict | list, path: CfnPath, region: str | None = None
     ):
         """
         Get a list of object values without conditions included.
@@ -1126,7 +1133,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
 
     def get_condition_scenarios_below_path(
         self,
-        path: Path,
+        path: CfnPath,
         include_if_in_function: bool = False,
         region: str | None = None,
     ) -> list[dict[str, bool]]:
@@ -1228,7 +1235,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
     def get_conditions_from_path(
         self,
         text: Any,
-        path: Path,
+        path: CfnPath,
         include_resource_conditions: bool = True,
         include_if_in_function: bool = True,
         only_last: bool = False,
@@ -1272,7 +1279,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
     def _get_conditions_from_path(
         self,
         text: Any,
-        path: Path,
+        path: CfnPath,
         include_if_in_function: bool = True,
         only_last: bool = False,
     ) -> dict[str, set[bool]]:
